##########
Gallery
##########

Here are some flexible practical examples of trackc

Cis contact map
===============

.. nbgallery::
    :caption: Varies heatmap
    :name: rst-gallery1
    :glob:
    :reversed:

    examples/mapc_eg

cell
===============

.. nbgallery::
    :caption: long range interactons
    :name: rst-gallery2
    :glob:
    :reversed:

    examples/long_range_interact

Advanced Science
=================

.. nbgallery::
    :caption: Rearranged interactions
    :name: rst-gallery3
    :glob:
    :reversed:

    examples/rearranged_interactions
    
AML 3DGenome
============

.. nbgallery::
    :caption: Enhancer hijacking
    :name: rst-gallery4
    :glob:
    :reversed:

    tutorials/Virtual4C
    